==> skirental_web_frontend-0.0.99.gem: README.md <==
# SkirentalWebFrontend

The rails frontend for the landingpage and the angular frontend for the shop/reservation pages *AS SUBMODULE*…
Checkout with:

```bash
git clone --recursive
```

If the project was already checked out before the Angular part got its own submodule do:

```bash
git submodule update --init --recursive
```

## Preconditions

### Install nodejs (minimum Version 8.11.3)

--> see <https://github.com/creationix/nvm>

### Install required packages

**All following commands must be executed in folder "frontend"** !

```bash
cd frontend
npm install
```

### Run (for development)

```bash
ng serve
```

## Build

### Prerequisites

make sure you have angular cli installed:

```bash
npm install -g @angular/cli
```

### Translation

First check package.json at `scripts.extract-i18n`. Does it contain all desired languages as parameters
for `xliffmerge` (`npm install` if not yet installed…)? Then run:

```bash
npm run extract-i18n
```

This command will update `messages.xlf` in `src/i18n` and apply changes to other XLIFF files: `i18n/messages.<locale>.xlf`.
If the source file `messages.xlf` was changed, upload it to the crowdin translation plattform:

```bash
brew install crowdin
crowdin upload sources
```

The translation will be done in crowdin. If new translations are avaible do:

```bash
crowdin download
```

or, if only one specific language should be updated (japanese for example):

```bash
crowdin download -l ja
```

### Execute build task

Go back to root directory of `skirental_web_frontend`
Enter: `rake app:angular:build`

### Also add new languages to sportsrental-lp-calendar project

*DO NOT FORGET:* if new languages were added, we need to update App.js to contain the corresponding moment.js module (see README in `sportsrental-lp-calendar`)

### Generate gem

1. Increment `lib/skirental_web_frontend/version.rb` (and version in package.json)
2. Exec `gem build skirental_web_frontend.gemspec`
3. Upload to gemserver.imhosting.de:3000

## Usage

How to use my plugin.

## Installation

Add this line to your application's Gemfile:

```ruby
gem 'skirental_web_frontend'
```

And then execute:

```bash
bundle
```

Or install it yourself as:

```bash
gem install skirental_web_frontend
```

## Contributing

Contribution directions go here.

## License

The gem is available as open source under the terms of the [MIT License](https://opensource.org/licenses/MIT).

==> skirental_web_frontend-1.1.14.gem: README.md <==
# SkirentalWebFrontend

The rails frontend for the landingpage and the angular frontend for the shop/reservation pages *AS SUBMODULE*…
Checkout with:

```bash
git clone --recursive
```

If the project was already checked out before the Angular part got its own submodule do:

```bash
git submodule update --init --recursive
```

## Preconditions

### Install nodejs (minimum Version 8.11.3)

--> see <https://github.com/creationix/nvm>

### Install required packages

**All following commands must be executed in folder "frontend"** !

```bash
cd frontend
npm install
```

### Run (for development)

```bash
ng serve
```

## Build

### Prerequisites

make sure you have angular cli installed:

```bash
npm install -g @angular/cli
```

### Translation

Run:

```bash
npm run extract-i18n
```

This command will update `template.json` in `src/i18n`.
If the file was changed, publish it to the customer for integration in the SR-API.

### Execute build task

Go back to root directory of `skirental_web_frontend`
Enter: `rake app:angular:build`

### Also add new languages to sportsrental-lp-calendar project

*DO NOT FORGET:* if new languages were added, we need to update App.js to contain the corresponding moment.js module (see README in `sportsrental-lp-calendar`)

### Generate gem

1. Increment `lib/skirental_web_frontend/version.rb` (and version in package.json)
2. Exec `gem build skirental_web_frontend.gemspec`
3. Upload to gemserver.imhosting.de:3000

## Usage

How to use my plugin.

## Installation

Add this line to your application's Gemfile:

```ruby
gem 'skirental_web_frontend'
```

And then execute:

```bash
bundle
```

Or install it yourself as:

```bash
gem install skirental_web_frontend
```

## Contributing

Contribution directions go here.

## License

The gem is available as open source under the terms of the [MIT License](https://opensource.org/licenses/MIT).
